import { createConnection } from "typeorm";
import { runSeeder } from 'typeorm-seeding';
import { config } from '../config';
import { User } from '../models/entities/User';
import SeedTestRunners from '../seeds/SeedTestRunners';
import SeedUsers from '../seeds/SeedUsers';
/**
 * Loader for the database that creates the database connection and initializes the database tabels.
 * It also triggers the seeding process if no users got detected in the database.
 */
export default async () => {
    const connection = await createConnection();
    await connection.synchronize();
    if (await connection.getRepository(User).count() === 0) {
        await runSeeder(SeedUsers);
    }
    if (config.seedTestData) {
        await runSeeder(SeedTestRunners);
    }
    return connection;
};